controller

package
v0.0.0-...-49e170d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2018 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Listen

func Listen(network, laddr string, config *tls.Config) (net.Listener, error)

Listen calls the net.Listen function returning a net.Listener or any error that occurred

func NewListener

func NewListener(inner net.Listener, config *tls.Config) net.Listener

NewListener creates a net.Listener with TLS config

Types

type Context

type Context struct {
	// Logger needs to be a pointer due to MutexWrap
	Logger        *logrus.Logger
	Settings      application.Settings
	MonitorClient monitor.Client
	ContainerPool *cntrpool.ContainerPool
}

Context is a struct representing all the components needed by a listener

func (*Context) StartListener

func (ctx *Context) StartListener(cm cntrmgr.ContainerManager) bool

StartListener is called when the application is ready to start serving connections from the pool

func (*Context) StartStatistics

func (ctx *Context) StartStatistics()

StartStatistics is called when the application is ready to start the statistics service

Jump to