Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Context ¶
type Context struct {
// Logger needs to be a pointer due to MutexWrap
Logger *logrus.Logger
Settings application.Settings
MonitorClient monitor.Client
ContainerPool *cntrpool.ContainerPool
}
Context is a struct representing all the components needed by a listener
func (*Context) StartListener ¶
func (ctx *Context) StartListener(cm cntrmgr.ContainerManager) bool
StartListener is called when the application is ready to start serving connections from the pool
func (*Context) StartStatistics ¶
func (ctx *Context) StartStatistics()
StartStatistics is called when the application is ready to start the statistics service
Click to show internal directories.
Click to hide internal directories.